.. SmartSVM documentation master file, created by
   sphinx-quickstart on Tue Sep 26 00:11:33 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

API documentation
=================

The documentation below is automatically generated from the docstrings in the 
code. It is therefore also available through the builtin Python ``help()`` 
function.

smartsvm\.base module
---------------------

.. automodule:: smartsvm.base
    :members:
    :undoc-members:
    :show-inheritance:

smartsvm\.cross\_connections module
-----------------------------------

.. automodule:: smartsvm.cross_connections
    :members:
    :undoc-members:
    :show-inheritance:

smartsvm\.cut module
--------------------

.. automodule:: smartsvm.cut
    :members:
    :undoc-members:
    :show-inheritance:

smartsvm\.divergence module
---------------------------

.. automodule:: smartsvm.divergence
    :members:
    :undoc-members:
    :show-inheritance:

smartsvm\.error\_estimate module
--------------------------------

.. automodule:: smartsvm.error_estimate
    :members:
    :undoc-members:
    :show-inheritance:

smartsvm\.smartsvm module
-------------------------

.. automodule:: smartsvm.smartsvm
    :members:
    :undoc-members:
    :show-inheritance:

smartsvm\.utils module
----------------------

.. automodule:: smartsvm.utils
    :members:
    :undoc-members:
    :show-inheritance:
